@@ -1,8 +1,10 @@
+from django.conf import settings
 from django.contrib import admin
 from djangoldp.admin import DjangoLDPAdmin
 from djangoldp.models import Model
 from djangoldp_community.models import Community, CommunityMember, CommunityCircle,\
     CommunityProject, CommunityJobOffer, CommunityProfile, CommunityAddress
+from importlib import import_module
 
 
 class EmptyAdmin(admin.ModelAdmin):
@@ -46,11 +48,27 @@ class AddressInline(admin.TabularInline):
     extra = 0
 
 
+djangoldp_modules = list(settings.DJANGOLDP_PACKAGES)
+community_inlines = [ProfileInline, AddressInline,
+                     MemberInline, CircleInline, ProjectInline, JobOfferInline]
+
+for dldp_module in djangoldp_modules:
+    try:
+        module_settings = import_module(dldp_module + '.settings')
+        module_community_inlines = module_settings.COMMUNITY_ADMIN_INLINES
+        for module in module_community_inlines:
+            module_admin = import_module(module[0])
+            community_inlines += [getattr(module_admin, module[1])]
+    except:
+        pass
+
+
 class CommunityAdmin(DjangoLDPAdmin):
     list_display = ('urlid', 'name', 'allow_self_registration')
     exclude = ('urlid', 'slug', 'is_backlink', 'allow_create_backlink')
-    inlines = [ProfileInline, AddressInline, MemberInline, CircleInline, ProjectInline, JobOfferInline]
-    search_fields = ['urlid', 'name', 'members__user__urlid', 'circles__circle__name']
+    inlines = community_inlines
+    search_fields = ['urlid', 'name',
+                     'members__user__urlid', 'circles__circle__name']
     ordering = ['urlid']
 
     def get_queryset(self, request):
