@@ -86,6 +86,8 @@ class CommunityPermissions(LDPPermissions):
                         perms = perms.union({'add'})
                 if community.allow_self_registration and ('slug' in resolved.kwargs and resolved.url_name == "community-communitymember-list"):
                     perms = perms.union({'add'})
+            elif (resolved.url_name == "open-communities-community-list" or resolved.url_name == "community-list"):
+                perms = perms.union({'add'})
 
         else:
             perms = self.get_object_permissions(request, view, obj)
